﻿define("frontifyintegration/editors/FrontifyThumbnailSelector", [
    // dojo
    "dojo/_base/declare",
    "dojo/when",
    "dojo/on",
    "dojo/topic",
    "dojo/dom-class",
    "dojo/ready",
    "dojo/_base/lang",
    // dijit
    "dijit/focus",
    "dijit/ProgressBar",
    // epi
    "epi/Url",
    "epi/routes",
    "epi/shell/dnd/Target",
    "epi/shell/DialogService",
    "epi/shell/XhrWrapper",
    // epi-cms
    "epi-cms/core/ContentReference",
    "epi-cms/widget/MediaSelector",
    "epi-cms/widget/ThumbnailSelector",
    "epi-cms/command/UploadContent",
    "epi-cms/widget/UploadUtil",
    "epi-cms/widget/viewmodel/MultipleFileUploadViewModel",
    "epi-cms/widget/LocalFolderUploader",
    "dojo/text!./templates/FrontifyThumbnailSelector.html",
    "dojo/text!./templates/FrontifyThumbnailSelectorDisableDefault.html",
    "frontifyintegration/legacy/LegacyDialogPopup",
    "epi/i18n!epi/cms/nls/episerver.cms.widget.thumbnailselector"
], function (
    // dojo
    declare,
    when,
    on,
    topic,
    domClass,
    ready,
    lang,
    // dijit
    focusManager,
    ProgressBar,
    // epi
    Url,
    routes,
    Target,
    dialogService,
    XhrWrapper,
    // epi-cms
    ContentReference,
    MediaSelector,
    ThumbnailSelector,
    UploadContent,
    UploadUtil,
    MultipleFileUploadViewModel,
    LocalFolderUploader,
    template,
    templateEpiDisabled,
    LegacyDialogPopup,
    resources
) {
    var xhr = new XhrWrapper();
    return declare([ThumbnailSelector], {
        // summary:
        //      Represents the widget to select ContentReference.
        // tags:
        //      internal

        resources: resources,

        loaded: false,
        uploadDisabledMessage: "Drag and drop feature has been disabled, please use Frontify.",
        pluginclientid: null,
        plugindomain: null,
        pluginpath: null,
        pluginversion: null,
        pluginiconpath: null,
        pluginWindow: null,
        activeElement: null,
        fwWin: null,
        pluginurl: null,
        timer: null,
        disableMediaSelector: null,
        listenerBound: false,
        //      List of file extensions that may be dropped onto the editor
        allowedExtensions: [],
        templateString: template,
        buildRendering: function () {
            //switching template depending on functionality
            this.templateString = this.disableMediaSelector === "True" ? templateEpiDisabled : template;
            this.inherited(arguments);
        },
        postCreate: function () {

            ready(setTimeout(lang.hitch(this, function () {//not optimal with timeout, but else not working with _setValue when used on init
                this.loaded = true;
            }), 100));

            this.allowedExtensions = this.pluginallowedfiletypes.replace(".", "").replace(/,/gi, "").split('.');

            this.inherited(arguments);
        },
        postFetchCf: function (data) {
            var self = this;
            return xhr.xhrPost({
                url: '/api/frontify/fetchcf',
                postData: JSON.stringify(data),
                handleAs: "text",
                headers: { "Content-Type": "application/json", "Accept": "application/json" },
                failOk: true,
                error: function (response) {
                    if (response.xhr.statusText !== "")
                        self._dialogService.alert(response.xhr.statusText);
                    else {
                        var mess = response.response.text.substring(0, response.response.text.length > 1500 ? 1500 : response.response.text.length);
                        self._dialogService.alert(mess);
                    }
                }
            });
        },
        // Custom function for Frontify integration to trigger opening of dialog.
        _onFrontifyButtonClick: function () {

            this.fwWin = new LegacyDialogPopup({
                url: "/plugin/frontify/index?clientId=" + this.pluginclientid + "&domain=" + this.plugindomain,
                onCallback: null,
                dialogArguments: {},
                dialogTitle: "Frontify Finder v2.0.0", // + this.pluginversion,
                autoFit: true,
                showCancelButton: true,
                showLoadingOverlay: true,
                features: { width: 1200, height: 540 }
            });
            this.fwWin.actionContainerNode.hidden = true;
            this.fwWin.show();

            if (!this.listenerBound) {
                this._listener = this._listener.bind(this);
                window.pluginWindow = this.fwWin;
                window.addEventListener("message", this._listener, true);
                this.listenerBound = true;
            }

            this.timer = setInterval(lang.hitch(this,
                function () {
                    if (!this.fwWin.open) {
                        window.removeEventListener("message", this._listener, true);
                        this.listenerBound = false;
                        clearInterval(this.timer);
                        return;
                    }
                }),
                2000);

        },
        _listener: function (event) {

            if (event.data.aborted !== undefined) {
                this.fwWin.hide();
                //remove listener
                window.removeEventListener("message", this._listener, true);
                this.listenerBound = false;
                return;
            }

            if (event.data.assetsChosen !== undefined) {
                this.fwWin.hide();
                this.assetsChosen(event.data.assetsChosen);
                //remove listener
                window.removeEventListener("message", this._listener, true);
                this.listenerBound = false;
                return;
            }
        },
        assetsChosen: function (assetsChosen) {
            var self = this;
            when(self.postFetchCf(assetsChosen),
                function (data) {
                    self.focus();
                    window.focus();
                    self._setValueAndFireOnChange(data + "");
                });
        },

        _setValueAttr: function (value) {
            if (this.disableMediaSelector === "True" && this.loaded && value != null) {
                this._dialogService.alert(this.uploadDisabledMessage);
                return;
            }
            this.inherited(arguments);
        },

        _onButtonClick: function () {
            if (this.readOnly) {
                return;
            }

            if (this.disableMediaSelector === "True") {
                this._onFrontifyButtonClick();
                return;
            }


            this.inherited(arguments);
        },

        _onClick: function () {
            if (this.readOnly) {
                return;
            }

            if (this.disableMediaSelector === "True") {
                this._onFrontifyButtonClick();
                return;
            }


            this.inherited(arguments);
        },

        _onDrop: function () {
            if (this.readOnly) {
                event.preventDefault();
                event.stopPropagation();
                return;
            }

            if (this.disableMediaSelector === "True") {
                this._dialogService.alert(this.uploadDisabledMessage);
                event.preventDefault();
                event.stopPropagation();
                return;
            }

            this.inherited(arguments);
        }
    });
});
