﻿"use strict";

/*
 * Simple proxy script that redirects incoming messages
 * to Frontify through an iframe. Message replies are
 * redirected back to caller.
 */

var _pagescriptcounter = 0;

var initpagescript = async function (accesstoken) {

    // Input commands to Frontify:
    //
    // init:    initialize communication
    // ping:    keep connection alive
    const incomingCommands = ['init', 'ping'];

    const iframe = document.getElementById('mainframe');

    const clientId = getQueryStringParameterByName('clientId');
    const domain = getQueryStringParameterByName('domain');

    // get origin/URL from query string
    var ivOrigin = getQueryStringParameterByName('frontifyBaseUrl');

    // init messaging
    window.addEventListener('message', messageEvent);

    /*
     * Handle message events.
     *
     * Forwards from opener to Frontify or returns from Frontify to opener.
     */
    function messageEvent(message) {
        if (verifyInputMessage(message)) {
            // forward message -> to Frontify
            iframe.contentWindow.postMessage(message.data, ivOrigin);
        } else {
            // reply to opener <- from Frontify
            if (window.opener)
                window.opener.postMessage(message.data, location.origin);
            else
                window.parent.postMessage(message.data, location.origin);
        }
    }


    /*
     * Verifies a message as input to Frontify:
     * Check that message origin is from us and make sure the message data is a valid input command.
     */
    function verifyInputMessage(message) {
        return incomingCommands.indexOf(message.data) !== -1 && message.origin === location.origin;
    }

    /*
     * Helper method to get specific query parameter from querystring
     */
    function getQueryStringParameterByName(name) {
        const url = window.location.href;
        name = name.replace(/[\[\]]/g, '\\$&');
        const regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)');
        const results = regex.exec(url);

        if (!results) {
            return '';
        }

        if (!results[2]) {
            return '';
        }

        return decodeURIComponent(results[2].replace(/\+/g, ' '));
    }

    try {
        // Create and Authorize the Finder
        const finder = await window.FrontifyFinder.create({
            domain: domain,
            clientId: clientId
        });

        // Add listener for assets chosen
        finder.onAssetsChosen(assets => {
            document.getElementById('finderModal').remove();
        });

        // Add listener for user abortion
        finder.onCancel(() => {
            document.getElementById('finderModal').remove();
        });

        // Mount the Finder into the DOM
        finder.mount(document.getElementById('finderModal'));

    } catch (error) {

        // Log error
        console.log(error);

        // Reenable your button
        document.getElementById('finderModal').remove();
    }
}

document.addEventListener('DOMContentLoaded', function () { initpagescript("") });
