﻿using Frontify.Optimizely.Plugin.Interfaces;
using Frontify.Optimizely.Plugin.Models;

namespace Frontify.AlloyMvcTemplates.Frontify;

public class DateTimeFolderResolver : IFolderResolver
{
    private readonly IFrontifySettings _frontifySettings;
    private readonly IContentRepository _contentRepository;

    public DateTimeFolderResolver(IFrontifySettings frontifySettings, IContentRepository contentRepository)
    {
        _frontifySettings = frontifySettings.GetCurrentInstance();
        _contentRepository = contentRepository;
    }

    public ContentReference GetAssetFolder(FrontifyAsset asset)
    {
        var childFolders = _contentRepository.GetChildren<ContentFolder>(_frontifySettings.RootFolderId);
        var year = DateTime.Now.Year.ToString();
        var month = DateTime.Now.Month.ToString();

        var yearFolder = childFolders.FirstOrDefault(f => string.Equals(f.Name, year, StringComparison.OrdinalIgnoreCase)) ?? CreateFolder(year, _frontifySettings.RootFolderId);
        var monthFolders = _contentRepository.GetChildren<ContentFolder>(yearFolder.ContentLink);
        var currentMonthFolder = monthFolders.FirstOrDefault(f => string.Equals(f.Name, month, StringComparison.OrdinalIgnoreCase)) ?? CreateFolder(month, yearFolder.ContentLink);

        return currentMonthFolder.ContentLink;
    }

    private ContentFolder CreateFolder(string folderName,ContentReference parentFolder)
    {
        var newFolder = _contentRepository.GetDefault<ContentFolder>(parentFolder);
        newFolder.Name = folderName;
        var folderReference =  _contentRepository.Save(newFolder);

        return _contentRepository.Get<ContentFolder>(folderReference);
    }
}