﻿using EPiServer.Shell.Rest;
using EPiServer.Web;
using EPiServer.Web.Routing;
using Frontify.Optimizely.Plugin;
using Frontify.Optimizely.Plugin.Interfaces;
using Frontify.Optimizely.Plugin.Property;
using Frontify.Optimizely.Plugin.Tinymce;

namespace Frontify.AlloyMvcTemplates.Frontify;
//[ServiceConfiguration(typeof(IFrontifyTinyMceTemplateResolver))]
// Example of FrontifyTinyMceTemplateResolver implementation for Tiny MCE insertion.
// Implement and register your custom instance in the IOC container to override default behaviour.
public class FrontifyTinyMceTemplateResolver : IFrontifyTinyMceTemplateResolver
{
    private readonly IContentLoader _contentLoader;
    private readonly UrlResolver _urlResolver;
    private readonly TemplateResolver _templateResolver;
    private readonly IFrontifySettings _frontifySettings;

    public FrontifyTinyMceTemplateResolver(IContentLoader contentLoader, UrlResolver urlResolver, TemplateResolver templateResolver, IFrontifySettings frontifySettings)
    {
        _contentLoader = contentLoader;
        _urlResolver = urlResolver;
        _templateResolver = templateResolver;
        _frontifySettings = frontifySettings;
    }
    /// <summary>
    /// By overriding, building a custom html image template to frontify insert in tiny mce
    /// </summary>
    /// <param name="contentReference">What image to use</param>
    /// <param name="insertingToContentReference">if you want to do some custom html depending on type of block or page</param>
    /// <param name="propname">The property on IContent used</param>
    /// <param name="width">The max size if set on property with FrontifyConfiguration</param>
    /// <returns>Custom image tag</returns>
    public string GetHtml(ContentReference contentReference, string? insertingToContentReference = null, string? propname = null, int? width = 0)
    {
        if (!_contentLoader.TryGet<MediaData>(contentReference, out var mediaData)) return "Content type not valid";


        bool useQueryParam = false;
        string queryParameters = null;

        if (!string.IsNullOrEmpty(insertingToContentReference))
        {
            var insertingTo = new ContentReference(insertingToContentReference).ToReferenceWithoutVersion();
            if (!_contentLoader.TryGet<IContent>(contentReference, out var contentOrBlock))
            {
                var attr = FrontifyAttributeHelper.GetPropertyAttributes(contentOrBlock, propname);
                if (attr != null)
                {
                    if (!string.IsNullOrEmpty(attr.QueryParameters))
                    {
                        useQueryParam = true;
                        queryParameters = attr.QueryParameters;
                    }
                    else if (attr.ImageWidth > 0)
                    {
                        useQueryParam = false;
                        width = attr.ImageWidth;
                    }
                }
            }
        }

        if (!useQueryParam)
        {
            var siteSettings = _frontifySettings.GetCurrentInstance();
            width = width > 0 ? width : siteSettings.DefaultTinyMceImageWidth > 0 ? siteSettings.DefaultTinyMceImageWidth : 1000;
        }

        if (mediaData is IFrontifyMedia frontifyImage)
        {
            var desc = mediaData.Property["Description"]?.Value ?? mediaData.Name;
            var url = frontifyImage.FrontifyUrl.FrontifyImage(new { width = width, QueryParameters = queryParameters });
            return $"<img src=\'{url}\' class=\'frontify-img\' alt=\'{desc}\'/>";
        }
        else
            return "Content type not valid";
    }
}